@@ -1,3 +1,4 @@
+# pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin,unused-import
 """
 Main interface for robomaker service client paginators.
 
@@ -28,9 +29,10 @@ Usage::
     list_simulation_jobs_paginator: ListSimulationJobsPaginator = client.get_paginator("list_simulation_jobs")
     ```
 """
-# pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
-from typing import Iterator, List, TYPE_CHECKING
+from typing import Iterator, List
+
 from botocore.paginate import Paginator as Boto3Paginator
+
 from mypy_boto3_robomaker.type_defs import (
     FilterTypeDef,
     ListDeploymentJobsResponseTypeDef,
@@ -43,7 +45,6 @@ from mypy_boto3_robomaker.type_defs import (
     PaginatorConfigTypeDef,
 )
 
-
 __all__ = (
     "ListDeploymentJobsPaginator",
     "ListFleetsPaginator",
@@ -57,33 +58,33 @@ __all__ = (
 
 class ListDeploymentJobsPaginator(Boto3Paginator):
     """
-    [Paginator.ListDeploymentJobs documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.0/reference/services/robomaker.html#RoboMaker.Paginator.ListDeploymentJobs)
+    [Paginator.ListDeploymentJobs documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.4/reference/services/robomaker.html#RoboMaker.Paginator.ListDeploymentJobs)
     """
 
     def paginate(
         self, filters: List[FilterTypeDef] = None, PaginationConfig: PaginatorConfigTypeDef = None
     ) -> Iterator[ListDeploymentJobsResponseTypeDef]:
         """
-        [ListDeploymentJobs.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.0/reference/services/robomaker.html#RoboMaker.Paginator.ListDeploymentJobs.paginate)
+        [ListDeploymentJobs.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.4/reference/services/robomaker.html#RoboMaker.Paginator.ListDeploymentJobs.paginate)
         """
 
 
 class ListFleetsPaginator(Boto3Paginator):
     """
-    [Paginator.ListFleets documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.0/reference/services/robomaker.html#RoboMaker.Paginator.ListFleets)
+    [Paginator.ListFleets documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.4/reference/services/robomaker.html#RoboMaker.Paginator.ListFleets)
     """
 
     def paginate(
         self, filters: List[FilterTypeDef] = None, PaginationConfig: PaginatorConfigTypeDef = None
     ) -> Iterator[ListFleetsResponseTypeDef]:
         """
-        [ListFleets.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.0/reference/services/robomaker.html#RoboMaker.Paginator.ListFleets.paginate)
+        [ListFleets.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.4/reference/services/robomaker.html#RoboMaker.Paginator.ListFleets.paginate)
         """
 
 
 class ListRobotApplicationsPaginator(Boto3Paginator):
     """
-    [Paginator.ListRobotApplications documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.0/reference/services/robomaker.html#RoboMaker.Paginator.ListRobotApplications)
+    [Paginator.ListRobotApplications documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.4/reference/services/robomaker.html#RoboMaker.Paginator.ListRobotApplications)
     """
 
     def paginate(
@@ -93,26 +94,26 @@ class ListRobotApplicationsPaginator(Boto3Paginator):
         PaginationConfig: PaginatorConfigTypeDef = None,
     ) -> Iterator[ListRobotApplicationsResponseTypeDef]:
         """
-        [ListRobotApplications.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.0/reference/services/robomaker.html#RoboMaker.Paginator.ListRobotApplications.paginate)
+        [ListRobotApplications.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.4/reference/services/robomaker.html#RoboMaker.Paginator.ListRobotApplications.paginate)
         """
 
 
 class ListRobotsPaginator(Boto3Paginator):
     """
-    [Paginator.ListRobots documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.0/reference/services/robomaker.html#RoboMaker.Paginator.ListRobots)
+    [Paginator.ListRobots documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.4/reference/services/robomaker.html#RoboMaker.Paginator.ListRobots)
     """
 
     def paginate(
         self, filters: List[FilterTypeDef] = None, PaginationConfig: PaginatorConfigTypeDef = None
     ) -> Iterator[ListRobotsResponseTypeDef]:
         """
-        [ListRobots.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.0/reference/services/robomaker.html#RoboMaker.Paginator.ListRobots.paginate)
+        [ListRobots.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.4/reference/services/robomaker.html#RoboMaker.Paginator.ListRobots.paginate)
         """
 
 
 class ListSimulationApplicationsPaginator(Boto3Paginator):
     """
-    [Paginator.ListSimulationApplications documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.0/reference/services/robomaker.html#RoboMaker.Paginator.ListSimulationApplications)
+    [Paginator.ListSimulationApplications documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.4/reference/services/robomaker.html#RoboMaker.Paginator.ListSimulationApplications)
     """
 
     def paginate(
@@ -122,31 +123,31 @@ class ListSimulationApplicationsPaginator(Boto3Paginator):
         PaginationConfig: PaginatorConfigTypeDef = None,
     ) -> Iterator[ListSimulationApplicationsResponseTypeDef]:
         """
-        [ListSimulationApplications.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.0/reference/services/robomaker.html#RoboMaker.Paginator.ListSimulationApplications.paginate)
+        [ListSimulationApplications.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.4/reference/services/robomaker.html#RoboMaker.Paginator.ListSimulationApplications.paginate)
         """
 
 
 class ListSimulationJobBatchesPaginator(Boto3Paginator):
     """
-    [Paginator.ListSimulationJobBatches documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.0/reference/services/robomaker.html#RoboMaker.Paginator.ListSimulationJobBatches)
+    [Paginator.ListSimulationJobBatches documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.4/reference/services/robomaker.html#RoboMaker.Paginator.ListSimulationJobBatches)
     """
 
     def paginate(
         self, filters: List[FilterTypeDef] = None, PaginationConfig: PaginatorConfigTypeDef = None
     ) -> Iterator[ListSimulationJobBatchesResponseTypeDef]:
         """
-        [ListSimulationJobBatches.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.0/reference/services/robomaker.html#RoboMaker.Paginator.ListSimulationJobBatches.paginate)
+        [ListSimulationJobBatches.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.4/reference/services/robomaker.html#RoboMaker.Paginator.ListSimulationJobBatches.paginate)
         """
 
 
 class ListSimulationJobsPaginator(Boto3Paginator):
     """
-    [Paginator.ListSimulationJobs documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.0/reference/services/robomaker.html#RoboMaker.Paginator.ListSimulationJobs)
+    [Paginator.ListSimulationJobs documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.4/reference/services/robomaker.html#RoboMaker.Paginator.ListSimulationJobs)
     """
 
     def paginate(
         self, filters: List[FilterTypeDef] = None, PaginationConfig: PaginatorConfigTypeDef = None
     ) -> Iterator[ListSimulationJobsResponseTypeDef]:
         """
-        [ListSimulationJobs.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.0/reference/services/robomaker.html#RoboMaker.Paginator.ListSimulationJobs.paginate)
+        [ListSimulationJobs.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.4/reference/services/robomaker.html#RoboMaker.Paginator.ListSimulationJobs.paginate)
         """
